| Title: | Interactively Insert Emojis in 'R' Documents |
|---|---|
| Description: | Provides an intuitive and user-friendly interface for working with emojis in 'R'. It allows users to search, insert, and manage emojis by keyword, category, or through an interactive 'shiny'-based drop-down. The package enables integration of emojis into 'R' scripts, 'R Markdown', 'Quarto', 'shiny' apps, and 'ggplot2' plots. Also includes built-in mappings for commit messages, useful for version control. It builds on established emoji libraries and Unicode standards, adding expressiveness and visual cues to documentation, user interfaces, and reports. For more details see 'Emojipedia' (2024) <https://emojipedia.org> and GitHub Emoji Cheat Sheet <https://github.com/ikatyang/emoji-cheat-sheet/tree/master>. |
| Authors: | Berhe Etsay Tesfay [aut, cre] (ORCID: <https://orcid.org/0000-0002-4625-1265>) |
| Maintainer: | Berhe Etsay Tesfay <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-14 06:12:26 UTC |
| Source: | https://github.com/3p1d3m/rmoji |
A list of emoji Unicode values with human-friendly names.
data(emoji_dict)data(emoji_dict)
A named list of emoji names and corresponding Unicode symbols.
data(emoji_dict) head(emoji_dict)data(emoji_dict) head(emoji_dict)
Prints all emoji names with their corresponding emoji symbols from the master list.
emoji_list()emoji_list()
prints the name of the emoji and the emoji image in the console
emoji_list()emoji_list()
Designed to be bound to a keyboard shortcut.
emoji_shortcut()emoji_shortcut()
Opens addin popup for emoji selection.
if (interactive()) { emoji_shortcut() }if (interactive()) { emoji_shortcut() }
Get emoji(s) for Git commit messages by name.
git_emoji(name)git_emoji(name)
name |
A character vector of emoji names (e.g., |
A named character vector of emojis.
git_emoji("fire") git_emoji(c("fire", "heart")) try(git_emoji(c("Ethiopia", "UK", "Kenya")))git_emoji("fire") git_emoji(c("fire", "heart")) try(git_emoji(c("Ethiopia", "UK", "Kenya")))
Inserts an emoji by name from the emoji_dict through writing the function in the cursor position of the Rstudio Document.
insert_emoji(name, default = NULL)insert_emoji(name, default = NULL)
name |
The name of the emoji (case-insensitive). |
default |
A default emoji to use if the name is not found. |
The emoji used (invisibly).
if (interactive()) { insert_emoji("smile") insert_emoji("notarealemoji", default = "?") }if (interactive()) { insert_emoji("smile") insert_emoji("notarealemoji", default = "?") }
For an R studio addin dropdown to insert emoji
insert_emoji_addin(test_input = NULL)insert_emoji_addin(test_input = NULL)
test_input |
For internal testing. If supplied, this will be used instead of prompting the user. |
Inserted emoji or NULL
This RStudio addin allows users to easily insert emojis by name into their R scripts, R Markdown, or Quarto documents. A Shiny-based GUI with a searchable dropdown will appear, allowing the user to select an emoji. Once an emoji is selected, it will be inserted at the cursor's position in the active editor.
shiny_emoji()shiny_emoji()
Inserts the selected emoji at the cursor position in the active R script or R Markdown document.
if (interactive()) { shiny_emoji() } # Use this addin by running shiny_emoji() from the RStudio Addins menu.if (interactive()) { shiny_emoji() } # Use this addin by running shiny_emoji() from the RStudio Addins menu.